JsonParserRegistry class
A ParserRegistry for JSON values.
- Inheritance
-
- Object
- ParserRegistry<
Json?> - JsonParserRegistry
Constructors
- JsonParserRegistry()
- Creates an empty registry with no registered parsers.
- JsonParserRegistry.withKnownParsers()
- Creates a registry pre-registered with the predefined parsers:
Properties
Methods
-
addParser<
T extends Object?> (Parser< T, Json?> parser) → void -
Registers a parser for the type
T.inherited -
getParser<
T extends Object?> () → Parser< T, Json?> ? -
Returns the parser for the type
T, or null if no parser was registered the for typeT.inherited -
getRuntimeParser(
Type typeOfT) → Parser< Object?, Json?> ? -
Returns the parser for the type
typeOfT, or null if no parser was registered the for typetypeOfT.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited